@@ -37,6 +37,8 @@
 #include <mutex>
 #include <thread>
 #include <stream/streammanager.h>
+#include <connectionplugins/connectionserial.h>
+#include <connectionplugins/connectiontcp.h>
 
 //JM 2019-01-17: Disabled until further notice
 //#define WITH_EXPOSURE_LOOPING
@@ -339,6 +341,25 @@ class SensorInterface : public DefaultDevice
         /** A function to just remove GCC warnings about deprecated conversion */
         void fits_update_key_s(fitsfile *fptr, int type, std::string name, void *p, std::string explanation, int *status);
 
+        /** Return the connection file descriptor */
+        int getPortFD()
+        {
+            return PortFD;
+        }
+
+        /** Export the serial connection object */
+        Connection::Serial *getSerialConnection()
+        {
+            return serialConnection;
+        }
+
+        /** Export the TCP connection object */
+        Connection::TCP *getTcpConnection()
+        {
+            return tcpConnection;
+        }
+
+
     protected:
 
         /**
@@ -511,9 +532,6 @@ class SensorInterface : public DefaultDevice
 
         std::unique_ptr<StreamManager> Streamer;
         std::unique_ptr<DSP::Manager> DSP;
-
-
-
         Connection::Serial *serialConnection = NULL;
         Connection::TCP *tcpConnection       = NULL;
 
